# Renkler
python için ile yapılmış türkçe renkler kütüphanesi

# Yükleme

rastgele renk için (pip install random)

pip install renkler

# Dökümantasyon

https://berkaykucuk.com.tr/blog/python-renkler-dokumantasyon/